#include "sequence-client.h"
#include "sequence-server.h"

static const CORBA::Long _oc_vec10[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    14, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x76656331), ACE_NTOHL(0x303a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:vec10:1.0 */,
    6, ACE_NTOHL(0x76656331), ACE_NTOHL(0x30000000) /* name = vec10 */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_long,
      10
};

static CORBA::TypeCode _tc_TAO_tc_vec10 (CORBA::tk_alias, sizeof(_oc_vec10), (char *) &_oc_vec10, 0, sizeof(vec10 ));

CORBA::TypeCode_ptr _tc_vec10 = &_tc_TAO_tc_vec10;

vec10::vec10()
  : _maximum(10),
    _length(0),
    _buffer(vec10::allocbuf(10)),
    _release(1)
{
}

vec10::vec10(CORBA::ULong length, CORBA::Long *buffer, CORBA::Boolean release)
  : _maximum(10),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

vec10::vec10(const vec10 &o)
  : _maximum(10),
    _length(o._length),
    _release(1)
{
  CORBA::Long  *tmp1 = vec10::allocbuf(this->_maximum);
  
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, o._buffer);
  
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  
  this->_buffer = tmp1;
}

vec10::~vec10()
{
  this->_deallocate_buffer();
}

vec10 &vec10::operator=(const vec10 &rhs)
{
  if( this == &rhs )
    return *this;
  if( this->_release )
  {
  
  
  }
  else
    this->_buffer = vec10::allocbuf(rhs._maximum);
  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Long  *tmp1 = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, rhs._buffer);
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  return *this;
}

CORBA::Long &vec10::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  return tmp[i];
}

const CORBA::Long &vec10::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * const tmp = ACE_reinterpret_cast(CORBA::Long  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Long *vec10::allocbuf(CORBA::ULong size)
{
  CORBA::Long  *tmp;
  tmp = new CORBA::Long [size];
  return tmp;
}

void vec10::freebuf(CORBA::Long *buffer)
{
  delete [] buffer;
}

void vec10::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Long  *tmp = vec10::allocbuf(length);
  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Long  *old = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];
    if( this->_release )
      vec10::freebuf(old);
  }
  this->_buffer = tmp;
}

void vec10::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;
  CORBA::Long  *tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  
  vec10::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean vec10::release() const
{
  return this->_release;
}

CORBA::ULong vec10::maximum() const
{
  return 10;
}

CORBA::ULong vec10::length() const
{
  return this->_length;
}

void vec10::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    return;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void vec10::_shrink_buffer(CORBA::ULong length1, CORBA::ULong length2)
{
}

CORBA::Long *vec10::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Long  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = vec10::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Long *vec10::get_buffer() const
{
  return ACE_const_cast(const CORBA::Long  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const vec10 &o)
{
  vec10  *_any_val;
  ACE_NEW(_any_val, vec10  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_vec10, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, vec10 *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_vec10, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, vec10 *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_vec10, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (vec10  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, vec10 , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_vec10, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_vec10, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

vec10_var::vec10_var()
  : ptr_(0)
{}

vec10_var::vec10_var(vec10 *p)
 : ptr_(p)
{}

vec10_var::vec10_var(const vec10_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new vec10 (*a.ptr_);
  else
    this->ptr_ = 0;
}

vec10_var::~vec10_var()
{
  delete this->ptr_;
}

vec10_var &vec10_var::operator=(vec10 *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

vec10_var &vec10_var::operator=(const vec10_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new vec10 (*p.ptr_);
  }
  return *this;
}

CORBA::Long &vec10_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &vec10_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

vec10 *vec10_var::operator->()
{
  return this->ptr_;
}

const vec10 *vec10_var::operator->() const
{
  return this->ptr_;
}

vec10_var::operator const vec10 &() const
{
  return *this->ptr_;
}

vec10_var::operator vec10 &()
{
  return *this->ptr_;
}

vec10_var::operator vec10 &() const
{
  return *this->ptr_;
}

const vec10 &vec10_var::in() const
{
  return *this->ptr_;
}

vec10 &vec10_var::inout()
{
  return *this->ptr_;
}

vec10 *&vec10_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

vec10 *vec10_var::_retn()
{
  vec10  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

vec10 *vec10_var::ptr() const
{
  return this->ptr_;
}

vec10_out::vec10_out(vec10 *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

vec10_out::vec10_out(vec10_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

vec10_out::vec10_out(const vec10_out &r)
  : ptr_(ACE_const_cast(vec10_out &,r).ptr_)
{}

vec10_out &vec10_out::operator=(const vec10_out &r)
{
  this->ptr_ = ACE_const_cast(vec10_out &,r).ptr_;
  return *this;
}

vec10_out &vec10_out::operator=(vec10 *r)
{
  this->ptr_ = r;
  return *this;
}

vec10_out::operator vec10 *&()
{
  return this->ptr_;
}

vec10 *&vec10_out::ptr()
{
  return this->ptr_;
}

CORBA::Long &vec10_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &vec10_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

vec10 *vec10_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_puke[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    13, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x70756b65), ACE_NTOHL(0x3a312e30), ACE_NTOHL(0x00000000) /* repository ID = IDL:puke:1.0 */,
    5, ACE_NTOHL(0x70756b65), ACE_NTOHL(0x00000000) /* name = puke */,
    1 /* member count */,
    7, ACE_NTOHL(0x72656173), ACE_NTOHL(0x6f6e0000) /* name = reason */,
    CORBA::tk_long
};

static CORBA::TypeCode _tc_TAO_tc_puke (CORBA::tk_except, sizeof(_oc_puke), (char *) &_oc_puke, 0, sizeof(puke ));

CORBA::TypeCode_ptr _tc_puke = &_tc_TAO_tc_puke;

puke::puke()
  : CORBA_UserException(_tc_puke)
{
}

puke::puke(const puke &o)
  : CORBA_UserException(o._type())
{
  this->reason = o.reason;
}

puke::~puke()
{}

puke &puke::operator=(const puke &o)
{
  this->CORBA_UserException::operator=(o);
  this->reason = o.reason;
  return *this;
}

void puke::_raise()
{
  TAO_RAISE(*this);
}

puke *puke::_narrow(CORBA::Exception *e)
{
  if( !(ACE_OS::strcmp("IDL:puke:1.0", e->_id())) )
    return ACE_dynamic_cast(puke_ptr , e);
  else
    return 0;
}

CORBA::Exception *puke::_alloc()
{
  return new puke ;
}

puke::puke(CORBA::Long _reason_)
  : CORBA_UserException(CORBA::TypeCode::_duplicate(_tc_puke))
{
  this->reason = _reason_;
}

void operator<<=(CORBA::Any &a, const puke &o)
{
  puke  *_any_val = new puke (o);
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_puke, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, puke *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_puke, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, puke *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_puke, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (puke  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, puke , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_puke, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_puke, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

static const CORBA::Long _oc_TestSeq[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    16, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x54657374), ACE_NTOHL(0x5365713a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:TestSeq:1.0 */,
    8, ACE_NTOHL(0x54657374), ACE_NTOHL(0x53657100) /* name = TestSeq */
};

static CORBA::TypeCode _tc_TAO_tc_TestSeq (CORBA::tk_objref, sizeof(_oc_TestSeq), (char *) &_oc_TestSeq, 0, sizeof(TestSeq ));

CORBA::TypeCode_ptr _tc_TestSeq = &_tc_TAO_tc_TestSeq;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<TestSeq >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<TestSeq >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */

TestSeq_ptr TestSeq::_duplicate(TestSeq_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

TestSeq_ptr TestSeq::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return TestSeq::_nil();
  if( !obj->_is_a("IDL:TestSeq:1.0", _env) )
    return TestSeq::_nil();
  return TestSeq::_unchecked_narrow(obj, _env);
}

TestSeq_ptr TestSeq::_unchecked_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return TestSeq::_nil();
  TAO_Stub *stub = obj->_stubobj();
  stub->_incr_refcnt();
  void* servant = 0;
  if (obj->_is_collocated () && obj->_servant() != 0)
    servant = obj->_servant()->_downcast ("IDL:Coffee:1.0");
  if (servant == 0)
    return new TestSeq (stub);
  return new _tao_collocated_TestSeq(
      ACE_reinterpret_cast(POA_TestSeq_ptr , servant),
      stub
    );
}

TestSeq_ptr TestSeq::_nil()
{
  return (TestSeq_ptr )NULL;
}

CORBA::Boolean TestSeq::_is_a(const CORBA::Char *type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)type_id, "IDL:TestSeq:1.0")) ||
      (!ACE_OS::strcmp((char *)type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(type_id, _env);
}

const char *TestSeq::_interface_repository_id() const
{
  return "IDL:TestSeq:1.0";
}

TestSeq::TestSeq()
{}

TestSeq::~TestSeq()
{}

void operator<<=(CORBA::Any &a, TestSeq_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = TestSeq::_duplicate(o);
    a.replace (_tc_TestSeq, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, TestSeq_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = TestSeq::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_TestSeq, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_TestSeq, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = TestSeq::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_TestSeq, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

TestSeq::TestSeq(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

TestSeq_var::TestSeq_var()
  : ptr_(TestSeq::_nil())
{}

TestSeq_var::TestSeq_var(TestSeq_ptr p)
  : ptr_(p)
{}

TestSeq_var::TestSeq_var(const TestSeq_var &a)
  : ptr_(TestSeq::_duplicate(a.ptr()))
{}

TestSeq_var::~TestSeq_var()
{
  CORBA::release(this->ptr_);
}

TestSeq_var &TestSeq_var::operator=(TestSeq_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

TestSeq_var &TestSeq_var::operator=(const TestSeq_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = TestSeq::_duplicate(p.ptr());
  }
  return *this;
}

TestSeq_ptr TestSeq_var::operator->() const
{
  return this->ptr_;
}

TestSeq_var::operator const TestSeq_ptr &() const
{
  return this->ptr_;
}

TestSeq_var::operator TestSeq_ptr &()
{
  return this->ptr_;
}

TestSeq_ptr TestSeq_var::in() const
{
  return this->ptr_;
}

TestSeq_ptr &TestSeq_var::inout()
{
  return this->ptr_;
}

TestSeq_ptr &TestSeq_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = TestSeq::_nil();
  return this->ptr_;
}

TestSeq_ptr TestSeq_var::_retn()
{
  TestSeq_ptr  val = this->ptr_;
  this->ptr_ = TestSeq::_nil();
  return val;
}

TestSeq_ptr TestSeq_var::ptr() const
{
  return this->ptr_;
}

TestSeq_out::TestSeq_out(TestSeq_ptr &r)
  : ptr_(r)
{
  this->ptr_ = TestSeq::_nil();
}

TestSeq_out::TestSeq_out(TestSeq_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = TestSeq::_nil();
}

TestSeq_out::TestSeq_out(const TestSeq_out &r)
  : ptr_(ACE_const_cast(TestSeq_out &,r).ptr_)
{}

TestSeq_out &TestSeq_out::operator=(const TestSeq_out &r)
{
  this->ptr_ = ACE_const_cast(TestSeq_out &,r).ptr_;
  return *this;
}

TestSeq_out &TestSeq_out::operator=(const TestSeq_var &r)
{
  this->ptr_ = TestSeq::_duplicate(r.ptr());
  return *this;
}

TestSeq_out &TestSeq_out::operator=(TestSeq_ptr r)
{
  this->ptr_ = r;
  return *this;
}

TestSeq_out::operator TestSeq_ptr &()
{
  return this->ptr_;
}

TestSeq_ptr &TestSeq_out::ptr()
{
  return this->ptr_;
}

TestSeq_ptr TestSeq_out::operator->()
{
  return this->ptr_;
}

int flick_marshal_stub(flick_marshal_stream_t _stream, const vec10 *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(44, _flick_abort0);
  flick_iiopxx_encode_new_chunk(4 + 4 * _data->_length);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  if (_data->_length > 10)
    flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort0);
  flick_cdr_encode_bcopy(4, _data->_buffer, 4 * _data->_length);
  flick_iiopxx_encode_end_chunk(4 + 4 * _data->_length);
  flick_iiopxx_encode_end_glob(44);
  return 0;
  {
  _flick_abort0:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub(flick_marshal_stream_t _stream, vec10 *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(44);
  flick_iiopxx_check_span(4, _flick_abort3);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  if (_data->_length > 10)
    flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort3);
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_check_span(4 * _data->_length * 1, _flick_abort3);
  flick_iiopxx_decode_new_chunk(4 * _data->_length);
  {
    CORBA::Long *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [10]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort3);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = 10;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 4 * _data->_length);
  flick_iiopxx_decode_end_chunk(4 * _data->_length);
  flick_iiopxx_decode_end_glob(44);
  return 0;
  {
  _flick_abort3:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_swap(flick_marshal_stream_t _stream, vec10 *_data)
{
  CORBA::ULong _t0_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(44);
  flick_iiopxx_check_span(4, _flick_abort6);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  if (_data->_length > 10)
    flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort6);
  flick_iiopxx_decode_end_chunk(4);
  {
    CORBA::Long *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [10]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort6);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = 10;
    _data->_release = 1;
  }
  flick_iiopxx_check_span(_data->_length * 4, _flick_abort6);
  for (_t0_array_iter = 0; _t0_array_iter < _data->_length; _t0_array_iter++)
    {
      flick_iiopxx_decode_new_chunk(4);
      flick_cdr_swap_decode_signed32(0, _data->_buffer[_t0_array_iter], CORBA::Long );
      flick_iiopxx_decode_end_chunk(4);
      continue;
    }
  flick_iiopxx_decode_end_glob(44);
  return 0;
  {
  _flick_abort6:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub(flick_marshal_stream_t _stream, const puke *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(4, _flick_abort12);
  flick_iiopxx_encode_new_chunk(4);
  flick_cdr_encode_signed32(0, _data->reason, CORBA::Long );
  flick_iiopxx_encode_end_chunk(4);
  flick_iiopxx_encode_end_glob(4);
  return 0;
  {
  _flick_abort12:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub(flick_marshal_stream_t _stream, puke *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort13);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_signed32(0, _data->reason, CORBA::Long );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  return 0;
  {
  _flick_abort13:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_swap(flick_marshal_stream_t _stream, puke *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(4);
  flick_iiopxx_check_span(4, _flick_abort14);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_signed32(0, _data->reason, CORBA::Long );
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_decode_end_glob(4);
  return 0;
  {
  _flick_abort14:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub(flick_marshal_stream_t _stream, const TestSeq_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, TestSeq , _flick_abort15);
  return 0;
  {
  _flick_abort15:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub(flick_marshal_stream_t _stream, TestSeq_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, TestSeq , _flick_abort16);
  return 0;
  {
  _flick_abort16:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_swap(flick_marshal_stream_t _stream, TestSeq_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, TestSeq , _flick_abort17);
  return 0;
  {
  _flick_abort17:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

vec10 *TestSeq::op(/* TestSeq *this, */ const vec10 &iv, vec10_out ov, vec10 &iov, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  vec10 *_return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort19);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort19);
    }
    {
      flick_iiopxx_encode_new_glob(100, _flick_abort19);
      flick_iiopxx_encode_new_chunk(16 + 4 * iv._length);
      flick_cdr_encode_unsigned32(0, 3, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(12, iv._length, CORBA::ULong );
      if (iv._length > 10)
        flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort19);
      flick_cdr_encode_bcopy(16, iv._buffer, 4 * iv._length);
      flick_iiopxx_encode_end_chunk(16 + 4 * iv._length);
      flick_iiopxx_encode_new_chunk(4 + 4 * iov._length);
      flick_cdr_encode_unsigned32(0, iov._length, CORBA::ULong );
      if (iov._length > 10)
        flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort19);
      flick_cdr_encode_bcopy(4, iov._buffer, 4 * iov._length);
      flick_iiopxx_encode_end_chunk(4 + 4 * iov._length);
      flick_iiopxx_encode_end_glob(100);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort19);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort19);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t24_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(136);
        flick_iiopxx_check_span(4, _flick_abort19);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t24_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t24_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t39_array_iter;
              CORBA::ULong _t40_array_iter;
              CORBA::ULong _t41_array_iter;

              /* Begin decode phase on parameters */
              {
                vec10 *_t_alloc_ptr;

                _t_alloc_ptr = (vec10 *)new vec10 ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort76);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(12, _flick_abort76);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              if (_return->_length > 10)
                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort76);
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_check_span(12 - 12 + 8 + _return->_length * 4, _flick_abort76);
              for (_t39_array_iter = 0; _t39_array_iter < _return->_length; _t39_array_iter++)
                {
                  flick_iiopxx_decode_new_chunk(4);
                  flick_cdr_swap_decode_signed32(0, _return->_buffer[_t39_array_iter], CORBA::Long );
                  flick_iiopxx_decode_end_chunk(4);
                  continue;
                }
              {
                vec10 *_t_alloc_ptr;

                _t_alloc_ptr = (vec10 *)new vec10 ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort76);
                ov = _t_alloc_ptr;
              }
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, ov->_length, CORBA::ULong );
              if (ov->_length > 10)
                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort76);
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_check_span(12 - 12 + 4 + ov->_length * 4, _flick_abort76);
              for (_t40_array_iter = 0; _t40_array_iter < ov->_length; _t40_array_iter++)
                {
                  flick_iiopxx_decode_new_chunk(4);
                  flick_cdr_swap_decode_signed32(0, ov->_buffer[_t40_array_iter], CORBA::Long );
                  flick_iiopxx_decode_end_chunk(4);
                  continue;
                }
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, iov._length, CORBA::ULong );
              if (iov._length > 10)
                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort76);
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_check_span(iov._length * 4, _flick_abort76);
              for (_t41_array_iter = 0; _t41_array_iter < iov._length; _t41_array_iter++)
                {
                  flick_iiopxx_decode_new_chunk(4);
                  flick_cdr_swap_decode_signed32(0, iov._buffer[_t41_array_iter], CORBA::Long );
                  flick_iiopxx_decode_end_chunk(4);
                  continue;
                }
              flick_iiopxx_decode_end_glob(136);
              break;
              {
              _flick_abort76:
                goto _flick_abort19;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(136);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort92);
              break;
              {
              _flick_abort92:
                goto _flick_abort19;
              }
            }
          default:
            {
              flick_corbaxx_env _t42_temp_env;
              unsigned int _t48_switch_tag;

              flick_iiopxx_check_span(24, _flick_abort93);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _t48_switch_tag, unsigned int );
              flick_iiopxx_decode_end_chunk(4);
              switch ((unsigned int )_t48_switch_tag)
                {
                case (unsigned int) 13:
                  {
                    unsigned int _t49_switch_tag;

                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t49_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t49_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t50_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t50_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t50_switch_tag)
                            {
                            case /* puke */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1886743397):
                              {
                                unsigned int _t51_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t51_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t51_switch_tag)
                                  {
                                  case /* :1.0 */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 976301616):
                                    {
                                      char _t52_switch_tag;

                                      flick_iiopxx_decode_new_chunk(1);
                                      flick_cdr_swap_decode_char8(0, _t52_switch_tag, char );
                                      flick_iiopxx_decode_end_chunk(1);
                                      switch ((char )_t52_switch_tag)
                                        {
                                        case 0:
                                          {
                                            _t42_temp_env._id = "IDL:puke:1.0";
                                            {
                                              puke *_t_alloc_ptr;

                                              _t_alloc_ptr = (puke *)new puke ;
                                              if (!_t_alloc_ptr)
                                                flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort96);
                                              _t42_temp_env._user_except = _t_alloc_ptr;
                                            }
                                            flick_iiopxx_decode_new_chunk(7);
                                            flick_cdr_swap_decode_signed32(3, ((puke *)(_t42_temp_env._user_except))->reason, CORBA::Long );
                                            flick_iiopxx_decode_end_chunk(7);
                                            break;
                                            {
                                            _flick_abort96:
                                              goto _flick_abort93;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort93);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort93);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort93);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort93);
                          break;
                        }
                      }
                    break;
                  }
                default:
                  {
                    flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort93);
                    break;
                  }
                }
              flick_corbaxx_exception_to_env(CORBA::Environment &, _ev, flick_corbaxx_env , _t42_temp_env);
              flick_iiopxx_decode_end_glob(136);
              break;
              {
              _flick_abort93:
                goto _flick_abort19;
              }
            }
          }
      }
    else
      {
        int _t1_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(136);
        flick_iiopxx_check_span(4, _flick_abort19);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t1_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t1_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                vec10 *_t_alloc_ptr;

                _t_alloc_ptr = (vec10 *)new vec10 ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort42);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(12, _flick_abort42);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              if (_return->_length > 10)
                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort42);
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_check_span(12 - 12 + 8 + 4 * _return->_length * 1, _flick_abort42);
              flick_iiopxx_decode_new_chunk(4 * _return->_length);
              flick_cdr_decode_bcopy(0, _return->_buffer, 4 * _return->_length);
              flick_iiopxx_decode_end_chunk(4 * _return->_length);
              {
                vec10 *_t_alloc_ptr;

                _t_alloc_ptr = (vec10 *)new vec10 ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort42);
                ov = _t_alloc_ptr;
              }
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, ov->_length, CORBA::ULong );
              if (ov->_length > 10)
                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort42);
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_check_span(12 - 12 + 4 + 4 * ov->_length * 1, _flick_abort42);
              flick_iiopxx_decode_new_chunk(4 * ov->_length);
              flick_cdr_decode_bcopy(0, ov->_buffer, 4 * ov->_length);
              flick_iiopxx_decode_end_chunk(4 * ov->_length);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, iov._length, CORBA::ULong );
              if (iov._length > 10)
                flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort42);
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_check_span(4 * iov._length * 1, _flick_abort42);
              flick_iiopxx_decode_new_chunk(4 * iov._length);
              flick_cdr_decode_bcopy(0, iov._buffer, 4 * iov._length);
              flick_iiopxx_decode_end_chunk(4 * iov._length);
              flick_iiopxx_decode_end_glob(136);
              break;
              {
              _flick_abort42:
                goto _flick_abort19;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(136);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort49);
              break;
              {
              _flick_abort49:
                goto _flick_abort19;
              }
            }
          default:
            {
              flick_corbaxx_env _t13_temp_env;
              unsigned int _t19_switch_tag;

              flick_iiopxx_check_span(24, _flick_abort50);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _t19_switch_tag, unsigned int );
              flick_iiopxx_decode_end_chunk(4);
              switch ((unsigned int )_t19_switch_tag)
                {
                case (unsigned int) 13:
                  {
                    unsigned int _t20_switch_tag;

                    flick_iiopxx_decode_new_chunk(4);
                    flick_cdr_decode_unsigned32(0, _t20_switch_tag, unsigned int );
                    flick_iiopxx_decode_end_chunk(4);
                    switch ((unsigned int )_t20_switch_tag)
                      {
                      case /* IDL: */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1229212730):
                        {
                          unsigned int _t21_switch_tag;

                          flick_iiopxx_decode_new_chunk(4);
                          flick_cdr_decode_unsigned32(0, _t21_switch_tag, unsigned int );
                          flick_iiopxx_decode_end_chunk(4);
                          switch ((unsigned int )_t21_switch_tag)
                            {
                            case /* puke */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 1886743397):
                              {
                                unsigned int _t22_switch_tag;

                                flick_iiopxx_decode_new_chunk(4);
                                flick_cdr_decode_unsigned32(0, _t22_switch_tag, unsigned int );
                                flick_iiopxx_decode_end_chunk(4);
                                switch ((unsigned int )_t22_switch_tag)
                                  {
                                  case /* :1.0 */ flick_cdr_convert_big_endian_to_local_unsigned32((unsigned int) 976301616):
                                    {
                                      char _t23_switch_tag;

                                      flick_iiopxx_decode_new_chunk(1);
                                      flick_cdr_decode_char8(0, _t23_switch_tag, char );
                                      flick_iiopxx_decode_end_chunk(1);
                                      switch ((char )_t23_switch_tag)
                                        {
                                        case 0:
                                          {
                                            _t13_temp_env._id = "IDL:puke:1.0";
                                            {
                                              puke *_t_alloc_ptr;

                                              _t_alloc_ptr = (puke *)new puke ;
                                              if (!_t_alloc_ptr)
                                                flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort53);
                                              _t13_temp_env._user_except = _t_alloc_ptr;
                                            }
                                            flick_iiopxx_decode_new_chunk(7);
                                            flick_cdr_decode_signed32(3, ((puke *)(_t13_temp_env._user_except))->reason, CORBA::Long );
                                            flick_iiopxx_decode_end_chunk(7);
                                            break;
                                            {
                                            _flick_abort53:
                                              goto _flick_abort50;
                                            }
                                          }
                                        default:
                                          {
                                            flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort50);
                                            break;
                                          }
                                        }
                                      break;
                                    }
                                  default:
                                    {
                                      flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort50);
                                      break;
                                    }
                                  }
                                break;
                              }
                            default:
                              {
                                flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort50);
                                break;
                              }
                            }
                          break;
                        }
                      default:
                        {
                          flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort50);
                          break;
                        }
                      }
                    break;
                  }
                default:
                  {
                    flick_stub_error(FLICK_ERROR_VOID_UNION, _flick_abort50);
                    break;
                  }
                }
              flick_corbaxx_exception_to_env(CORBA::Environment &, _ev, flick_corbaxx_env , _t13_temp_env);
              flick_iiopxx_decode_end_glob(136);
              break;
              {
              _flick_abort50:
                goto _flick_abort19;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort19:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort18);
    _flick_abort18:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

