#include "simple-client.h"
#include "simple-server.h"

static const CORBA::Long _oc_vec10[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    14, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x76656331), ACE_NTOHL(0x303a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:vec10:1.0 */,
    6, ACE_NTOHL(0x76656331), ACE_NTOHL(0x30000000) /* name = vec10 */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_long,
      10
};

static CORBA::TypeCode _tc_TAO_tc_vec10 (CORBA::tk_alias, sizeof(_oc_vec10), (char *) &_oc_vec10, 0, sizeof(vec10 ));

CORBA::TypeCode_ptr _tc_vec10 = &_tc_TAO_tc_vec10;

vec10::vec10()
  : _maximum(10),
    _length(0),
    _buffer(vec10::allocbuf(10)),
    _release(1)
{
}

vec10::vec10(CORBA::ULong length, CORBA::Long *buffer, CORBA::Boolean release)
  : _maximum(10),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

vec10::vec10(const vec10 &o)
  : _maximum(10),
    _length(o._length),
    _release(1)
{
  CORBA::Long  *tmp1 = vec10::allocbuf(this->_maximum);
  
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, o._buffer);
  
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  
  this->_buffer = tmp1;
}

vec10::~vec10()
{
  this->_deallocate_buffer();
}

vec10 &vec10::operator=(const vec10 &rhs)
{
  if( this == &rhs )
    return *this;
  if( this->_release )
  {
  
  
  }
  else
    this->_buffer = vec10::allocbuf(rhs._maximum);
  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Long  *tmp1 = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  CORBA::Long  * const tmp2 = ACE_reinterpret_cast(CORBA::Long  * ACE_CAST_CONST, rhs._buffer);
  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];
  return *this;
}

CORBA::Long &vec10::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  return tmp[i];
}

const CORBA::Long &vec10::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Long  * const tmp = ACE_reinterpret_cast(CORBA::Long  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Long *vec10::allocbuf(CORBA::ULong size)
{
  CORBA::Long  *tmp;
  tmp = new CORBA::Long [size];
  return tmp;
}

void vec10::freebuf(CORBA::Long *buffer)
{
  delete [] buffer;
}

void vec10::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Long  *tmp = vec10::allocbuf(length);
  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Long  *old = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];
    if( this->_release )
      vec10::freebuf(old);
  }
  this->_buffer = tmp;
}

void vec10::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;
  CORBA::Long  *tmp = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
  
  vec10::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean vec10::release() const
{
  return this->_release;
}

CORBA::ULong vec10::maximum() const
{
  return 10;
}

CORBA::ULong vec10::length() const
{
  return this->_length;
}

void vec10::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    return;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void vec10::_shrink_buffer(CORBA::ULong length1, CORBA::ULong length2)
{
}

CORBA::Long *vec10::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Long  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = vec10::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Long  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Long *vec10::get_buffer() const
{
  return ACE_const_cast(const CORBA::Long  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const vec10 &o)
{
  vec10  *_any_val;
  ACE_NEW(_any_val, vec10  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_vec10, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, vec10 *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_vec10, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, vec10 *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_vec10, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (vec10  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, vec10 , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_vec10, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_vec10, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

vec10_var::vec10_var()
  : ptr_(0)
{}

vec10_var::vec10_var(vec10 *p)
 : ptr_(p)
{}

vec10_var::vec10_var(const vec10_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new vec10 (*a.ptr_);
  else
    this->ptr_ = 0;
}

vec10_var::~vec10_var()
{
  delete this->ptr_;
}

vec10_var &vec10_var::operator=(vec10 *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

vec10_var &vec10_var::operator=(const vec10_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new vec10 (*p.ptr_);
  }
  return *this;
}

CORBA::Long &vec10_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &vec10_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

vec10 *vec10_var::operator->()
{
  return this->ptr_;
}

const vec10 *vec10_var::operator->() const
{
  return this->ptr_;
}

vec10_var::operator const vec10 &() const
{
  return *this->ptr_;
}

vec10_var::operator vec10 &()
{
  return *this->ptr_;
}

vec10_var::operator vec10 &() const
{
  return *this->ptr_;
}

const vec10 &vec10_var::in() const
{
  return *this->ptr_;
}

vec10 &vec10_var::inout()
{
  return *this->ptr_;
}

vec10 *&vec10_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

vec10 *vec10_var::_retn()
{
  vec10  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

vec10 *vec10_var::ptr() const
{
  return this->ptr_;
}

vec10_out::vec10_out(vec10 *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

vec10_out::vec10_out(vec10_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

vec10_out::vec10_out(const vec10_out &r)
  : ptr_(ACE_const_cast(vec10_out &,r).ptr_)
{}

vec10_out &vec10_out::operator=(const vec10_out &r)
{
  this->ptr_ = ACE_const_cast(vec10_out &,r).ptr_;
  return *this;
}

vec10_out &vec10_out::operator=(vec10 *r)
{
  this->ptr_ = r;
  return *this;
}

vec10_out::operator vec10 *&()
{
  return this->ptr_;
}

vec10 *&vec10_out::ptr()
{
  return this->ptr_;
}

CORBA::Long &vec10_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Long &vec10_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

vec10 *vec10_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_simple[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    15, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c653a31), ACE_NTOHL(0x2e300000) /* repository ID = IDL:simple:1.0 */,
    7, ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c650000) /* name = simple */
};

static CORBA::TypeCode _tc_TAO_tc_simple (CORBA::tk_objref, sizeof(_oc_simple), (char *) &_oc_simple, 0, sizeof(simple ));

CORBA::TypeCode_ptr _tc_simple = &_tc_TAO_tc_simple;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<simple >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<simple >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */

simple_ptr simple::_duplicate(simple_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

simple_ptr simple::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return simple::_nil();
  if( !obj->_is_a("IDL:simple:1.0", _env) )
    return simple::_nil();
  return simple::_unchecked_narrow(obj, _env);
}

simple_ptr simple::_unchecked_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return simple::_nil();
  TAO_Stub *stub = obj->_stubobj();
  stub->_incr_refcnt();
  void* servant = 0;
  if (obj->_is_collocated () && obj->_servant() != 0)
    servant = obj->_servant()->_downcast ("IDL:Coffee:1.0");
  if (servant == 0)
    return new simple (stub);
  return new _tao_collocated_simple(
      ACE_reinterpret_cast(POA_simple_ptr , servant),
      stub
    );
}

simple_ptr simple::_nil()
{
  return (simple_ptr )NULL;
}

CORBA::Boolean simple::_is_a(const CORBA::Char *type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)type_id, "IDL:simple:1.0")) ||
      (!ACE_OS::strcmp((char *)type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(type_id, _env);
}

const char *simple::_interface_repository_id() const
{
  return "IDL:simple:1.0";
}

simple::simple()
{}

simple::~simple()
{}

void operator<<=(CORBA::Any &a, simple_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = simple::_duplicate(o);
    a.replace (_tc_simple, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, simple_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = simple::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_simple, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_simple, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = simple::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_simple, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

simple::simple(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

simple_var::simple_var()
  : ptr_(simple::_nil())
{}

simple_var::simple_var(simple_ptr p)
  : ptr_(p)
{}

simple_var::simple_var(const simple_var &a)
  : ptr_(simple::_duplicate(a.ptr()))
{}

simple_var::~simple_var()
{
  CORBA::release(this->ptr_);
}

simple_var &simple_var::operator=(simple_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

simple_var &simple_var::operator=(const simple_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = simple::_duplicate(p.ptr());
  }
  return *this;
}

simple_ptr simple_var::operator->() const
{
  return this->ptr_;
}

simple_var::operator const simple_ptr &() const
{
  return this->ptr_;
}

simple_var::operator simple_ptr &()
{
  return this->ptr_;
}

simple_ptr simple_var::in() const
{
  return this->ptr_;
}

simple_ptr &simple_var::inout()
{
  return this->ptr_;
}

simple_ptr &simple_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple::_nil();
  return this->ptr_;
}

simple_ptr simple_var::_retn()
{
  simple_ptr  val = this->ptr_;
  this->ptr_ = simple::_nil();
  return val;
}

simple_ptr simple_var::ptr() const
{
  return this->ptr_;
}

simple_out::simple_out(simple_ptr &r)
  : ptr_(r)
{
  this->ptr_ = simple::_nil();
}

simple_out::simple_out(simple_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple::_nil();
}

simple_out::simple_out(const simple_out &r)
  : ptr_(ACE_const_cast(simple_out &,r).ptr_)
{}

simple_out &simple_out::operator=(const simple_out &r)
{
  this->ptr_ = ACE_const_cast(simple_out &,r).ptr_;
  return *this;
}

simple_out &simple_out::operator=(const simple_var &r)
{
  this->ptr_ = simple::_duplicate(r.ptr());
  return *this;
}

simple_out &simple_out::operator=(simple_ptr r)
{
  this->ptr_ = r;
  return *this;
}

simple_out::operator simple_ptr &()
{
  return this->ptr_;
}

simple_ptr &simple_out::ptr()
{
  return this->ptr_;
}

simple_ptr simple_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_simple2[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    16, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c65323a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:simple2:1.0 */,
    8, ACE_NTOHL(0x73696d70), ACE_NTOHL(0x6c653200) /* name = simple2 */
};

static CORBA::TypeCode _tc_TAO_tc_simple2 (CORBA::tk_objref, sizeof(_oc_simple2), (char *) &_oc_simple2, 0, sizeof(simple2 ));

CORBA::TypeCode_ptr _tc_simple2 = &_tc_TAO_tc_simple2;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<simple2 >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<simple2 >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */

simple2_ptr simple2::_duplicate(simple2_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

simple2_ptr simple2::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return simple2::_nil();
  if( !obj->_is_a("IDL:simple2:1.0", _env) )
    return simple2::_nil();
  return simple2::_unchecked_narrow(obj, _env);
}

simple2_ptr simple2::_unchecked_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if( CORBA::is_nil(obj) )
    return simple2::_nil();
  TAO_Stub *stub = obj->_stubobj();
  stub->_incr_refcnt();
  void* servant = 0;
  if (obj->_is_collocated () && obj->_servant() != 0)
    servant = obj->_servant()->_downcast ("IDL:Coffee:1.0");
  if (servant == 0)
    return new simple2 (stub);
  return new _tao_collocated_simple2(
      ACE_reinterpret_cast(POA_simple2_ptr , servant),
      stub
    );
}

simple2_ptr simple2::_nil()
{
  return (simple2_ptr )NULL;
}

CORBA::Boolean simple2::_is_a(const CORBA::Char *type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)type_id, "IDL:simple:1.0")) ||
      (!ACE_OS::strcmp((char *)type_id, "IDL:simple2:1.0")) ||
      (!ACE_OS::strcmp((char *)type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(type_id, _env);
}

const char *simple2::_interface_repository_id() const
{
  return "IDL:simple2:1.0";
}

simple2::simple2()
{}

simple2::~simple2()
{}

void operator<<=(CORBA::Any &a, simple2_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = simple2::_duplicate(o);
    a.replace (_tc_simple2, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, simple2_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = simple2::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_simple2, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_simple2, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = simple2::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_simple2, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

simple2::simple2(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

simple2_var::simple2_var()
  : ptr_(simple2::_nil())
{}

simple2_var::simple2_var(simple2_ptr p)
  : ptr_(p)
{}

simple2_var::simple2_var(const simple2_var &a)
  : ptr_(simple2::_duplicate(a.ptr()))
{}

simple2_var::~simple2_var()
{
  CORBA::release(this->ptr_);
}

simple2_var &simple2_var::operator=(simple2_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

simple2_var &simple2_var::operator=(const simple2_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = simple2::_duplicate(p.ptr());
  }
  return *this;
}

simple2_ptr simple2_var::operator->() const
{
  return this->ptr_;
}

simple2_var::operator const simple2_ptr &() const
{
  return this->ptr_;
}

simple2_var::operator simple2_ptr &()
{
  return this->ptr_;
}

simple2_ptr simple2_var::in() const
{
  return this->ptr_;
}

simple2_ptr &simple2_var::inout()
{
  return this->ptr_;
}

simple2_ptr &simple2_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple2::_nil();
  return this->ptr_;
}

simple2_ptr simple2_var::_retn()
{
  simple2_ptr  val = this->ptr_;
  this->ptr_ = simple2::_nil();
  return val;
}

simple2_ptr simple2_var::ptr() const
{
  return this->ptr_;
}

simple2_out::simple2_out(simple2_ptr &r)
  : ptr_(r)
{
  this->ptr_ = simple2::_nil();
}

simple2_out::simple2_out(simple2_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = simple2::_nil();
}

simple2_out::simple2_out(const simple2_out &r)
  : ptr_(ACE_const_cast(simple2_out &,r).ptr_)
{}

simple2_out &simple2_out::operator=(const simple2_out &r)
{
  this->ptr_ = ACE_const_cast(simple2_out &,r).ptr_;
  return *this;
}

simple2_out &simple2_out::operator=(const simple2_var &r)
{
  this->ptr_ = simple2::_duplicate(r.ptr());
  return *this;
}

simple2_out &simple2_out::operator=(simple2_ptr r)
{
  this->ptr_ = r;
  return *this;
}

simple2_out::operator simple2_ptr &()
{
  return this->ptr_;
}

simple2_ptr &simple2_out::ptr()
{
  return this->ptr_;
}

simple2_ptr simple2_out::operator->()
{
  return this->ptr_;
}

int flick_marshal_stub(flick_marshal_stream_t _stream, const vec10 *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_iiopxx_encode_new_glob(44, _flick_abort0);
  flick_iiopxx_encode_new_chunk(4 + 4 * _data->_length);
  flick_cdr_encode_unsigned32(0, _data->_length, CORBA::ULong );
  if (_data->_length > 10)
    flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort0);
  flick_cdr_encode_bcopy(4, _data->_buffer, 4 * _data->_length);
  flick_iiopxx_encode_end_chunk(4 + 4 * _data->_length);
  flick_iiopxx_encode_end_glob(44);
  return 0;
  {
  _flick_abort0:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub(flick_marshal_stream_t _stream, vec10 *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(44);
  flick_iiopxx_check_span(4, _flick_abort3);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_decode_unsigned32(0, _data->_length, CORBA::ULong );
  if (_data->_length > 10)
    flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort3);
  flick_iiopxx_decode_end_chunk(4);
  flick_iiopxx_check_span(4 * _data->_length * 1, _flick_abort3);
  flick_iiopxx_decode_new_chunk(4 * _data->_length);
  {
    CORBA::Long *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [10]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort3);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = 10;
    _data->_release = 1;
  }
  flick_cdr_decode_bcopy(0, _data->_buffer, 4 * _data->_length);
  flick_iiopxx_decode_end_chunk(4 * _data->_length);
  flick_iiopxx_decode_end_glob(44);
  return 0;
  {
  _flick_abort3:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_swap(flick_marshal_stream_t _stream, vec10 *_data)
{
  CORBA::ULong _t0_array_iter;

  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_iiopxx_decode_new_glob(44);
  flick_iiopxx_check_span(4, _flick_abort6);
  flick_iiopxx_decode_new_chunk(4);
  flick_cdr_swap_decode_unsigned32(0, _data->_length, CORBA::ULong );
  if (_data->_length > 10)
    flick_stub_error(FLICK_ERROR_OUT_OF_BOUNDS, _flick_abort6);
  flick_iiopxx_decode_end_chunk(4);
  {
    CORBA::Long *_t_alloc_ptr;

    _t_alloc_ptr = (CORBA::Long *)new (CORBA::Long [10]);
    if (!_t_alloc_ptr)
      flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort6);
    _data->_buffer = _t_alloc_ptr;
    _data->_maximum = 10;
    _data->_release = 1;
  }
  flick_iiopxx_check_span(_data->_length * 4, _flick_abort6);
  for (_t0_array_iter = 0; _t0_array_iter < _data->_length; _t0_array_iter++)
    {
      flick_iiopxx_decode_new_chunk(4);
      flick_cdr_swap_decode_signed32(0, _data->_buffer[_t0_array_iter], CORBA::Long );
      flick_iiopxx_decode_end_chunk(4);
      continue;
    }
  flick_iiopxx_decode_end_glob(44);
  return 0;
  {
  _flick_abort6:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_marshal_stub(flick_marshal_stream_t _stream, const simple_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, simple , _flick_abort12);
  return 0;
  {
  _flick_abort12:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub(flick_marshal_stream_t _stream, simple_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, simple , _flick_abort13);
  return 0;
  {
  _flick_abort13:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_swap(flick_marshal_stream_t _stream, simple_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, simple , _flick_abort14);
  return 0;
  {
  _flick_abort14:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

CORBA::Long simple::op(/* simple *this, */ CORBA::Long a, simple_out b, CORBA::Long &c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  CORBA::Long _return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort16);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort16);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort16);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 3, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(12, a, CORBA::Long );
      flick_cdr_encode_signed32(16, c, CORBA::Long );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort16);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort16);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t2_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort16);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t2_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t2_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(8, _flick_abort29);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_swapxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort29);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort29);
              flick_cdr_swap_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort29:
                goto _flick_abort16;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort30);
              break;
              {
              _flick_abort30:
                goto _flick_abort16;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort31);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort31:
                goto _flick_abort16;
              }
            }
          }
      }
    else
      {
        int _t1_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort16);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t1_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t1_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(8, _flick_abort22);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdrxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort22);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort22);
              flick_cdr_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort22:
                goto _flick_abort16;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort23);
              break;
              {
              _flick_abort23:
                goto _flick_abort16;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort24);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort24:
                goto _flick_abort16;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort16:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort15);
    _flick_abort15:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

int flick_marshal_stub(flick_marshal_stream_t _stream, const simple2_ptr *_data)
{
  _stub_state.state = FLICK_STATE_MARSHAL;
  flick_cdrxx_encode_IOR(iiopxx, *_data, 0, simple2 , _flick_abort32);
  return 0;
  {
  _flick_abort32:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub(flick_marshal_stream_t _stream, simple2_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdrxx_decode_IOR(iiopxx, *_data, 1, simple2 , _flick_abort33);
  return 0;
  {
  _flick_abort33:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

int flick_unmarshal_stub_swap(flick_marshal_stream_t _stream, simple2_ptr *_data)
{
  _stub_state.state = FLICK_STATE_UNMARSHAL;
  flick_cdr_swapxx_decode_IOR(iiopxx, *_data, 1, simple2 , _flick_abort34);
  return 0;
  {
  _flick_abort34:
    goto _flick_reaper;
  }
_flick_reaper:
  return 1;
}

CORBA::Long simple2::op2(/* simple2 *this, */ CORBA::Long a, simple_ptr b, simple2_out c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  CORBA::Long _return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort36);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort36);
    }
    {
      flick_iiopxx_encode_new_glob(16, _flick_abort36);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 4, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, '2', flick_char8_t );
      flick_cdr_encode_char8(7, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(12, a, CORBA::Long );
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
      flick_cdrxx_encode_IOR(iiopxx, b, 0, simple , _flick_abort36);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort36);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort36);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t4_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort36);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t4_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t4_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort49);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_swapxx_decode_IOR(iiopxx, c, 1, simple2 , _flick_abort49);
              break;
              {
              _flick_abort49:
                goto _flick_abort36;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort50);
              break;
              {
              _flick_abort50:
                goto _flick_abort36;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort51);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort51:
                goto _flick_abort36;
              }
            }
          }
      }
    else
      {
        int _t3_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort36);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t3_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t3_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(4, _flick_abort42);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdrxx_decode_IOR(iiopxx, c, 1, simple2 , _flick_abort42);
              break;
              {
              _flick_abort42:
                goto _flick_abort36;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort43);
              break;
              {
              _flick_abort43:
                goto _flick_abort36;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort44);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort44:
                goto _flick_abort36;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort36:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort35);
    _flick_abort35:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

CORBA::Long simple2::op(/* simple2 *this, */ CORBA::Long a, simple_out b, CORBA::Long &c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;
  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();
  CORBA::Long _return;

  _return = 0;
  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
      ACE_CDR::DEFAULT_BUFSIZE,
      TAO_ENCAP_BYTE_ORDER,
      _orb_core->output_cdr_buffer_allocator(),
      _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR _in_cdr(_orb_core->create_input_cdr_data_block(ACE_CDR::DEFAULT_BUFSIZE),
      TAO_ENCAP_BYTE_ORDER);
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry ();
    TAO_Transport *_transport;
    TAO_Profile *_tp;
    CORBA::ULong _my_request_id = 0;
    _tp = _istub->profile_in_use();
    if( _conn_reg->connect (_istub, _transport) )
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort53);
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort53);
    }
    {
      flick_iiopxx_encode_new_glob(20, _flick_abort53);
      flick_iiopxx_encode_new_chunk(20);
      flick_cdr_encode_unsigned32(0, 3, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(8, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(12, a, CORBA::Long );
      flick_cdr_encode_signed32(16, c, CORBA::Long );
      flick_iiopxx_encode_end_chunk(20);
      flick_iiopxx_encode_end_glob(20);
    }
    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;
    flick_iiopxx_client_set_response_expected(1);
    if( _transport->send_request(_orb_core,_out_cdr, 1) == -1 ) {
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort53);
    }
    else {
      _stub_state.state = FLICK_STATE_RECEIVE;
      TAO_GIOP::Message_Type _msg_type = TAO_GIOP::recv_request(_transport, _in_cdr, _orb_core);
      _transport->resume_connection(_orb_core->reactor());
      switch(_msg_type)
      {
      case TAO_GIOP::Reply:
        break;
      case TAO_GIOP::Request:
      case TAO_GIOP::CancelRequest:
      case TAO_GIOP::LocateRequest:
      case TAO_GIOP::LocateReply:
      case TAO_GIOP::CommunicationError:
      case TAO_GIOP::MessageError:
      case TAO_GIOP::EndOfFile:
      default:
      case TAO_GIOP::CloseConnection:
        _transport->close_connection();
        _tp->reset_hint();
        _istub->reset_profiles();
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort53);
        break;
      }
      _transport->idle();
    }
    flick_iiopxx_client_start_decode();
    if (_in_cdr.do_byte_swap())
      {
        int _t6_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort53);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t6_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t6_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(8, _flick_abort66);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_swapxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort66);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort66);
              flick_cdr_swap_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort66:
                goto _flick_abort53;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort67);
              break;
              {
              _flick_abort67:
                goto _flick_abort53;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort68);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort68:
                goto _flick_abort53;
              }
            }
          }
      }
    else
      {
        int _t5_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort53);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t5_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t5_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              flick_iiopxx_check_span(8, _flick_abort59);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdrxx_decode_IOR(iiopxx, b, 1, simple , _flick_abort59);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort59);
              flick_cdr_decode_signed32(0, c, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort59:
                goto _flick_abort53;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort60);
              break;
              {
              _flick_abort60:
                goto _flick_abort53;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort61);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort61:
                goto _flick_abort53;
              }
            }
          }
      }
    flick_iiopxx_client_end_decode();
    return _return;
    {
    _flick_abort53:
      flick_corbaxx_client_error(cdr, iiopxx, _flick_abort52);
    _flick_abort52:
      goto _flick_reaper;
    }
  }
_flick_reaper:
  return _return;
}

